@@ -2,7 +2,7 @@ require 'spec_helper'
 
 describe 'octavia::db::sync' do
 
-  shared_examples_for 'octavia-dbsync' do
+  shared_examples_for 'octavia::db::sync' do
 
     it { is_expected.to contain_class('octavia::deps') }
 
@@ -43,8 +43,8 @@ describe 'octavia::db::sync' do
           :timeout     => 750,
           :logoutput   => 'on_failure',
           :subscribe   => ['Anchor[octavia::install::end]',
-                         'Anchor[octavia::config::end]',
-                         'Anchor[octavia::dbsync::begin]'],
+                           'Anchor[octavia::config::end]',
+                           'Anchor[octavia::dbsync::begin]'],
           :notify      => 'Anchor[octavia::dbsync::end]',
           :tag         => 'openstack-db',
         )
@@ -58,13 +58,10 @@ describe 'octavia::db::sync' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge(OSDefaults.get_facts({
-          :os_workers     => 8,
-          :concat_basedir => '/var/lib/puppet/concat'
-        }))
+        facts.merge(OSDefaults.get_facts())
       end
 
-      it_configures 'octavia-dbsync'
+      it_configures 'octavia::db::sync'
     end
   end
 
