@@ -39,6 +39,7 @@ describe 'octavia' do
           :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
           :heartbeat_rate                  => '<SERVICE DEFAULT>',
           :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
+          :rabbit_qos_prefetch_count       => '<SERVICE DEFAULT>',
           :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
           :kombu_reconnect_delay           => '<SERVICE DEFAULT>',
           :kombu_failover_strategy         => '<SERVICE DEFAULT>',
@@ -53,27 +54,13 @@ describe 'octavia' do
           :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
-        )
-        is_expected.to contain_oslo__messaging__amqp('octavia_config').with(
-          :server_request_prefix => '<SERVICE DEFAULT>',
-          :broadcast_prefix      => '<SERVICE DEFAULT>',
-          :group_request_prefix  => '<SERVICE DEFAULT>',
-          :container_name        => '<SERVICE DEFAULT>',
-          :idle_timeout          => '<SERVICE DEFAULT>',
-          :trace                 => '<SERVICE DEFAULT>',
-          :ssl_ca_file           => '<SERVICE DEFAULT>',
-          :ssl_cert_file         => '<SERVICE DEFAULT>',
-          :ssl_key_file          => '<SERVICE DEFAULT>',
-          :sasl_mechanisms       => '<SERVICE DEFAULT>',
-          :sasl_config_dir       => '<SERVICE DEFAULT>',
-          :sasl_config_name      => '<SERVICE DEFAULT>',
-          :username              => '<SERVICE DEFAULT>',
-          :password              => '<SERVICE DEFAULT>',
+          :enable_cancel_on_failover       => '<SERVICE DEFAULT>',
         )
         should contain_oslo__messaging__notifications('octavia_config').with(
           :transport_url => '<SERVICE DEFAULT>',
           :driver        => '<SERVICE DEFAULT>',
           :topics        => '<SERVICE DEFAULT>',
+          :retry         => '<SERVICE DEFAULT>',
         )
       end
     end
@@ -93,11 +80,13 @@ describe 'octavia' do
           :rabbit_heartbeat_timeout_threshold => '60',
           :rabbit_heartbeat_rate              => '10',
           :rabbit_heartbeat_in_pthread        => true,
+          :rabbit_qos_prefetch_count          => 0,
           :rabbit_quorum_queue                => true,
           :rabbit_transient_quorum_queue      => true,
           :rabbit_quorum_delivery_limit       => 3,
           :rabbit_quorum_max_memory_length    => 5,
           :rabbit_quorum_max_memory_bytes     => 1073741824,
+          :rabbit_enable_cancel_on_failover   => false,
           :kombu_compression                  => 'gzip',
           :kombu_reconnect_delay              => '5.0',
           :kombu_failover_strategy            => 'shuffle',
@@ -106,6 +95,7 @@ describe 'octavia' do
           :notification_transport_url         => 'rabbit://rabbit_user:password@localhost:5673',
           :notification_driver                => 'ceilometer.compute.octavia_notifier',
           :notification_topics                => 'openstack',
+          :notification_retry                 => 10,
           :topic                              => 'oct-rpc',
         }
       end
@@ -122,6 +112,7 @@ describe 'octavia' do
           :heartbeat_timeout_threshold     => '60',
           :heartbeat_rate                  => '10',
           :heartbeat_in_pthread            => true,
+          :rabbit_qos_prefetch_count       => 0,
           :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
           :kombu_reconnect_delay           => '5.0',
           :kombu_failover_strategy         => 'shuffle',
@@ -136,11 +127,13 @@ describe 'octavia' do
           :rabbit_quorum_delivery_limit    => 3,
           :rabbit_quorum_max_memory_length => 5,
           :rabbit_quorum_max_memory_bytes  => 1073741824,
+          :enable_cancel_on_failover       => false,
         )
         should contain_oslo__messaging__notifications('octavia_config').with(
           :transport_url => 'rabbit://rabbit_user:password@localhost:5673',
           :driver        => 'ceilometer.compute.octavia_notifier',
           :topics        => 'openstack',
+          :retry         => 10,
         )
       end
 
@@ -198,42 +191,6 @@ describe 'octavia' do
         )
       end
     end
-
-    context 'with overridden amqp parameters' do
-      let :params do
-        { :default_transport_url => 'amqp://amqp_user:password@localhost:5672',
-          :amqp_idle_timeout     => '60',
-          :amqp_trace            => true,
-          :amqp_ssl_ca_file      => '/etc/ca.cert',
-          :amqp_ssl_cert_file    => '/etc/certfile',
-          :amqp_ssl_key_file     => '/etc/key',
-          :amqp_username         => 'amqp_user',
-          :amqp_password         => 'password',
-        }
-      end
-
-      it 'configures amqp' do
-        is_expected.to contain_oslo__messaging__default('octavia_config').with(
-          :transport_url => 'amqp://amqp_user:password@localhost:5672'
-        )
-        is_expected.to contain_oslo__messaging__amqp('octavia_config').with(
-          :server_request_prefix => '<SERVICE DEFAULT>',
-          :broadcast_prefix      => '<SERVICE DEFAULT>',
-          :group_request_prefix  => '<SERVICE DEFAULT>',
-          :container_name        => '<SERVICE DEFAULT>',
-          :idle_timeout          => '60',
-          :trace                 => true,
-          :ssl_ca_file           => '/etc/ca.cert',
-          :ssl_cert_file         => '/etc/certfile',
-          :ssl_key_file          => '/etc/key',
-          :sasl_mechanisms       => '<SERVICE DEFAULT>',
-          :sasl_config_dir       => '<SERVICE DEFAULT>',
-          :sasl_config_name      => '<SERVICE DEFAULT>',
-          :username              => 'amqp_user',
-          :password              => 'password',
-        )
-      end
-    end
   end
 
   on_supported_os({
